@@ -26,6 +26,9 @@ module WebMockHelper
 
   def response_for(response_file, options = {})
     response = {}
+    response[:headers] = {
+      'Content-Type': 'application/json'
+    }
     response[:body] = File.new(File.join(File.dirname(__FILE__), '../mock_json', "#{response_file}.json"))
     if options[:status]
       response[:status] = options[:status]
@@ -35,4 +38,4 @@ module WebMockHelper
 end
 
 include WebMockHelper
-WebMock.disable_net_connect!
\ No newline at end of file
+WebMock.disable_net_connect!
